@@ -798,6 +798,28 @@ undo_delete (EEditorPage *editor_page,
 		else
 			range = get_range_for_point (document, event->after.start);
 
+		/* If redoing an INPUT event that was done in the middle of the
+		 * text we need to move one character backward as the range is
+		 * pointing after the character and not before it - for INPUT
+		 * events we don't save the before coordinates. */
+		if (event->type == HISTORY_INPUT) {
+			glong start_offset;
+			WebKitDOMNode *start_container;
+
+			start_offset = webkit_dom_range_get_start_offset (range, NULL);
+			start_container = webkit_dom_range_get_start_container (range, NULL);
+
+			if (WEBKIT_DOM_IS_CHARACTER_DATA (start_container) &&
+			    start_offset != webkit_dom_character_data_get_length (WEBKIT_DOM_CHARACTER_DATA (start_container))) {
+				webkit_dom_range_set_start (
+					range,
+					start_container,
+					start_offset > 0 ? start_offset - 1 : 0,
+					NULL);
+				webkit_dom_range_collapse (range, TRUE, NULL);
+			}
+		}
+
 		webkit_dom_range_surround_contents (range, WEBKIT_DOM_NODE (element), NULL);
 		webkit_dom_dom_selection_remove_all_ranges (dom_selection);
 		webkit_dom_dom_selection_add_range (dom_selection, range);
@@ -937,27 +959,18 @@ redo_delete (EEditorPage *editor_page,
              EEditorHistoryEvent *event)
 {
 	EEditorUndoRedoManager *manager;
-	WebKitDOMDocument *document;
 	WebKitDOMDocumentFragment *fragment = event->data.fragment;
 	WebKitDOMNode *node;
-	WebKitDOMHTMLElement *body;
-	gboolean delete_key, control_key, html_mode;
+	gboolean delete_key, control_key;
 	glong length = 1;
 	gint ii;
 
 	manager = e_editor_page_get_undo_redo_manager (editor_page);
-	document = e_editor_page_get_document (editor_page);
-	html_mode = e_editor_page_get_html_mode (editor_page);
 	restore_selection_to_history_event_state (editor_page, event->before);
 
 	delete_key = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (event->data.fragment), "history-delete-key"));
 	control_key = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (event->data.fragment), "history-control-key"));
 
-	body = webkit_dom_document_get_body (document);
-
-	if (!html_mode)
-		e_editor_dom_set_monospace_font_family_on_body (WEBKIT_DOM_ELEMENT (body), TRUE);
-
 	if (!delete_key && e_editor_dom_key_press_event_process_backspace_key (editor_page))
 		goto out;
 
@@ -1034,8 +1047,6 @@ redo_delete (EEditorPage *editor_page,
 	e_editor_page_set_renew_history_after_coordinates (editor_page, FALSE);
 	e_editor_dom_body_key_up_event_process_backspace_or_delete (editor_page, delete_key);
 	e_editor_page_set_renew_history_after_coordinates (editor_page, TRUE);
-	if (!html_mode)
-		e_editor_dom_set_monospace_font_family_on_body (WEBKIT_DOM_ELEMENT (body), FALSE);
 
 	restore_selection_to_history_event_state (editor_page, event->after);
 
@@ -2232,8 +2243,11 @@ e_editor_undo_redo_manager_set_operation_in_progress (EEditorUndoRedoManager *ma
 }
 
 static void
-free_history_event_content (EEditorHistoryEvent *event)
+free_history_event (EEditorHistoryEvent *event)
 {
+	if (event == NULL)
+		return;
+
 	switch (event->type) {
 		case HISTORY_INPUT:
 		case HISTORY_DELETE:
@@ -2272,15 +2286,6 @@ free_history_event_content (EEditorHistoryEvent *event)
 		default:
 			break;
 	}
-}
-
-static void
-free_history_event (EEditorHistoryEvent *event)
-{
-	if (event == NULL)
-		return;
-
-	free_history_event_content (event);
 
 	g_free (event);
 }
@@ -2289,8 +2294,7 @@ static void
 remove_history_event (EEditorUndoRedoManager *manager,
                       GList *item)
 {
-	free_history_event_content (item->data);
-
+	free_history_event (item->data);
 	manager->priv->history = g_list_delete_link (manager->priv->history, item);
 	manager->priv->history_size--;
 }
